@@ -2,8 +2,6 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-from __future__ import absolute_import
-
 from base64 import b64encode, b64decode
 from collections import OrderedDict
 from os.path import isfile
@@ -11,12 +9,13 @@ import datetime
 import json
 import os
 import pkg_resources
-import sys
 import time
 import bisect
 import warnings
 import re
 
+from html import escape
+
 try:
     from ansi2html import Ansi2HTMLConverter, style
 
@@ -30,16 +29,6 @@ from py.xml import html, raw
 from . import extras
 from . import __version__, __pypi_url__
 
-PY3 = sys.version_info[0] == 3
-
-# Python 2.X and 3.X compatibility
-if PY3:
-    basestring = str
-    from html import escape
-else:
-    from codecs import open
-    from cgi import escape
-
 
 def pytest_addhooks(pluginmanager):
     from . import hooks
@@ -80,9 +69,7 @@ def pytest_configure(config):
     if htmlpath:
         for csspath in config.getoption("css"):
             if not os.path.exists(csspath):
-                raise IOError(
-                    "No such file or directory: '{csspath}'".format(csspath=csspath)
-                )
+                raise IOError(f"No such file or directory: '{csspath}'")
         if not hasattr(config, "slaveinput"):
             # prevent opening htmlpath on slave nodes (xdist)
             config._html = HTMLReport(htmlpath, config)
@@ -98,10 +85,10 @@ def pytest_unconfigure(config):
 
 def data_uri(content, mime_type="text/plain", charset="utf-8"):
     data = b64encode(content.encode(charset)).decode("ascii")
-    return "data:{0};charset={1};base64,{2}".format(mime_type, charset, data)
+    return f"data:{mime_type};charset={charset};base64,{data}"
 
 
-class HTMLReport(object):
+class HTMLReport:
     def __init__(self, logfile, config):
         logfile = os.path.expanduser(os.path.expandvars(logfile))
         self.logfile = os.path.abspath(logfile)
@@ -139,7 +126,7 @@ class HTMLReport(object):
             cells = [
                 html.td(self.outcome, class_="col-result"),
                 html.td(self.test_id, class_="col-name"),
-                html.td("{0:.2f}".format(self.time), class_="col-duration"),
+                html.td(f"{self.time:.2f}", class_="col-duration"),
                 html.td(self.links_html, class_="col-links"),
             ]
 
@@ -184,7 +171,7 @@ class HTMLReport(object):
             if not os.path.exists(os.path.dirname(asset_path)):
                 os.makedirs(os.path.dirname(asset_path))
 
-            relative_path = "{0}/{1}".format("assets", asset_file_name)
+            relative_path = f"assets/{asset_file_name}"
 
             kwargs = {"encoding": "utf-8"} if "b" not in mode else {}
             with open(asset_path, mode, **kwargs) as f:
@@ -212,13 +199,10 @@ class HTMLReport(object):
                         )
                     html_div = html.a(html.img(src=content), href=content)
                 elif self.self_contained:
-                    src = "data:{0};base64,{1}".format(extra.get("mime_type"), content)
+                    src = "data:{};base64,{}".format(extra.get("mime_type"), content)
                     html_div = html.img(src=src)
                 else:
-                    if PY3:
-                        content = content.encode("utf-8")
-
-                    content = b64decode(content)
+                    content = b64decode(content.encode("utf-8"))
                     href = src = self.create_asset(
                         content, extra_index, test_index, extra.get("extension"), "wb"
                     )
@@ -279,7 +263,7 @@ class HTMLReport(object):
 
             for section in report.sections:
                 header, content = map(escape, section)
-                log.append(" {0} ".format(header).center(80, "-"))
+                log.append(f" {header:-^80} ")
                 log.append(html.br())
                 if ANSI:
                     converter = Ansi2HTMLConverter(inline=False, escaped=False)
@@ -299,7 +283,7 @@ class HTMLReport(object):
             self.results.insert(index, result)
             tbody = html.tbody(
                 result.row_table,
-                class_="{0} results-table-row".format(result.outcome.lower()),
+                class_="{} results-table-row".format(result.outcome.lower()),
             )
             if result.row_extra is not None:
                 tbody.append(result.row_extra)
@@ -348,9 +332,7 @@ class HTMLReport(object):
 
         self.style_css = pkg_resources.resource_string(
             __name__, os.path.join("resources", "style.css")
-        )
-        if PY3:
-            self.style_css = self.style_css.decode("utf-8")
+        ).decode("utf-8")
 
         if ANSI:
             ansi_css = [
@@ -365,12 +347,12 @@ class HTMLReport(object):
         for path in self.config.getoption("css"):
             self.style_css += "\n/******************************"
             self.style_css += "\n * CUSTOM CSS"
-            self.style_css += "\n * {}".format(path)
+            self.style_css += f"\n * {path}"
             self.style_css += "\n ******************************/\n\n"
             with open(path, "r") as f:
                 self.style_css += f.read()
 
-        css_href = "{0}/{1}".format("assets", "style.css")
+        css_href = "assets/style.css"
         html_css = html.link(href=css_href, rel="stylesheet", type="text/css")
         if self.self_contained:
             html_css = html.style(raw(self.style_css))
@@ -404,12 +386,12 @@ class HTMLReport(object):
                     name="filter_checkbox",
                     class_="filter",
                     hidden="true",
-                    **checkbox_kwargs
+                    **checkbox_kwargs,
                 )
 
             def generate_summary_item(self):
                 self.summary_item = html.span(
-                    "{0} {1}".format(self.total, self.label), class_=self.class_html
+                    f"{self.total} {self.label}", class_=self.class_html
                 )
 
         outcomes = [
@@ -425,9 +407,7 @@ class HTMLReport(object):
             outcomes.append(Outcome("rerun", self.rerun))
 
         summary = [
-            html.p(
-                "{0} tests ran in {1:.2f} seconds. ".format(numtests, suite_time_delta)
-            ),
+            html.p(f"{numtests} tests ran in {suite_time_delta:.2f} seconds. "),
             html.p(
                 "(Un)check the boxes to filter the results.",
                 class_="filter",
@@ -475,19 +455,17 @@ class HTMLReport(object):
 
         main_js = pkg_resources.resource_string(
             __name__, os.path.join("resources", "main.js")
-        )
-        if PY3:
-            main_js = main_js.decode("utf-8")
+        ).decode("utf-8")
 
         body = html.body(
             html.script(raw(main_js)),
             html.h1(os.path.basename(self.logfile)),
             html.p(
-                "Report generated on {0} at {1} by ".format(
+                "Report generated on {} at {} by ".format(
                     generated.strftime("%d-%b-%Y"), generated.strftime("%H:%M:%S")
                 ),
                 html.a("pytest-html", href=__pypi_url__),
-                " v{0}".format(__version__),
+                f" v{__version__}",
             ),
             onLoad="init()",
         )
@@ -504,12 +482,11 @@ class HTMLReport(object):
 
         doc = html.html(head, body)
 
-        unicode_doc = u"<!DOCTYPE html>\n{0}".format(doc.unicode(indent=2))
-        if PY3:
-            # Fix encoding issues, e.g. with surrogates
-            unicode_doc = unicode_doc.encode("utf-8", errors="xmlcharrefreplace")
-            unicode_doc = unicode_doc.decode("utf-8")
-        return unicode_doc
+        unicode_doc = "<!DOCTYPE html>\n{}".format(doc.unicode(indent=2))
+
+        # Fix encoding issues, e.g. with surrogates
+        unicode_doc = unicode_doc.encode("utf-8", errors="xmlcharrefreplace")
+        return unicode_doc.decode("utf-8")
 
     def _generate_environment(self, config):
         if not hasattr(config, "_metadata") or config._metadata is None:
@@ -525,10 +502,10 @@ class HTMLReport(object):
 
         for key in keys:
             value = metadata[key]
-            if isinstance(value, basestring) and value.startswith("http"):
+            if isinstance(value, str) and value.startswith("http"):
                 value = html.a(value, href=value, target="_blank")
             elif isinstance(value, (list, tuple, set)):
-                value = ", ".join((str(i) for i in value))
+                value = ", ".join(str(i) for i in value)
             rows.append(html.tr(html.td(key), html.td(value)))
 
         environment.append(html.table(rows, id="environment"))
@@ -572,6 +549,4 @@ class HTMLReport(object):
         self._save_report(report_content)
 
     def pytest_terminal_summary(self, terminalreporter):
-        terminalreporter.write_sep(
-            "-", "generated html file: file://{0}".format(self.logfile)
-        )
+        terminalreporter.write_sep("-", f"generated html file: file://{self.logfile}")
